@@ -13,7 +13,7 @@ class PrettyJSONSerializer(Serializer):
                 sort_keys=True, ensure_ascii=False, indent=self.json_indent)
 
 class UserJSONSerializer(Serializer):     
-    json_indent = 4
+    json_indent = 0
 
     def to_json(self, data, options=None):
         options = options or {}
@@ -25,7 +25,8 @@ class UserJSONSerializer(Serializer):
                 sort_keys=True, ensure_ascii=False, indent=self.json_indent)
           
 class CourseJSONSerializer(Serializer):
-
+    json_indent = 0
+    
     def to_json(self, data, options=None):
         options = options or {}
         data = self.to_simple(data, options)
@@ -34,12 +35,5 @@ class CourseJSONSerializer(Serializer):
             data['courses'] = data['objects']
             del data['objects']
 
-        return json.dumps(data,  sort_keys=True)
-
-class TagJSONSerializer(Serializer):
-    json_indent = 4
-    def to_json(self, data, options=None):
-        options = options or {}
-        data = self.to_simple(data, options)
-    
-        return json.dumps(data, sort_keys=True, ensure_ascii=False)
\ No newline at end of file
+        return json.dumps(data,
+                sort_keys=True, ensure_ascii=False, indent=self.json_indent)
\ No newline at end of file
