@@ -6,14 +6,31 @@ from django.contrib.auth import (authenticate, login, views)
 from django.contrib.auth.models import User
 from django.core.mail import send_mail
 from django.core.paginator import Paginator, InvalidPage, EmptyPage
+from django.core.urlresolvers import reverse
 from django.http import HttpResponseRedirect, Http404
 from django.shortcuts import render
 from django.utils.translation import ugettext as _
 
 from oppia.models import Points,Award, AwardCourse, Course, UserProfile
-from oppia.profile.forms import RegisterForm, ResetForm, ProfileForm
+from oppia.profile.forms import LoginForm, RegisterForm, ResetForm, ProfileForm
 from tastypie.models import ApiKey
 
+
+def login_view(request):
+    username = password = ''
+    if request.POST:
+        form = LoginForm(request.POST)
+        username = request.POST.get('username')
+        password = request.POST.get('password')
+        user = authenticate(username=username, password=password)
+        if user is not None and user.is_active:
+            login(request,user)
+            return HttpResponseRedirect(reverse('oppia_home'))
+    else:
+        form = LoginForm()
+        
+    return render(request, 'oppia/form.html',{'username': username, 'form': form, 'title': _(u'Login')})
+
 def register(request):
     if not settings.OPPIA_ALLOW_SELF_REGISTRATION:
         raise Http404
@@ -43,7 +60,7 @@ def register(request):
     else:
         form = RegisterForm() # An unbound form
 
-    return render(request, 'oppia/profile/register.html', {'form': form,})
+    return render(request, 'oppia/form.html', {'form': form, 'title': _(u'Register')})
 
 def reset(request):
     if request.method == 'POST': # if form submitted...
@@ -67,12 +84,12 @@ def reset(request):
     else:
         form = ResetForm() # An unbound form
 
-    return render(request, 'oppia/profile/reset.html', {'form': form,})
+    return render(request, 'oppia/form.html', {'form': form,'title': _(u'Reset password')})
 
 def edit(request):
     key = ApiKey.objects.get(user = request.user)
     if request.method == 'POST':
-        form = ProfileForm(request.POST,request=request)
+        form = ProfileForm(request.POST)
         if form.is_valid():
             # update basic data
             email = form.cleaned_data.get("email")
@@ -96,7 +113,7 @@ def edit(request):
                                     'email':request.user.email,
                                     'first_name':request.user.first_name,
                                     'last_name':request.user.last_name,
-                                    'api_key': key.key},request=request)
+                                    'api_key': key.key})
         
     return render(request, 'oppia/profile/profile.html', {'form': form,})
 
