@@ -8,4 +8,6 @@ class UserLocationVisualization (models.Model):
     lat = models.FloatField()
     lng = models.FloatField()
     region = models.TextField(blank=True)
-    country = models.CharField(max_length=100)
+    country_code = models.CharField(max_length=100, blank=True, null=True, default=None)
+    country_name = models.TextField(blank=True, null=True, default=None)
+    geonames_data = models.TextField(blank=True, null=True, default=None)
